# coding: utf-8

"""
    SIGNATE API

    API for Public  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Error(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'code': 'str',
        'message': 'str',
        'required_agreement': 'object',
        'validations': 'object'
    }

    attribute_map = {
        'code': 'code',
        'message': 'message',
        'required_agreement': 'requiredAgreement',
        'validations': 'validations'
    }

    def __init__(self, code=None, message=None, required_agreement=None, validations=None):  # noqa: E501
        """Error - a model defined in Swagger"""  # noqa: E501

        self._code = None
        self._message = None
        self._required_agreement = None
        self._validations = None
        self.discriminator = None

        if code is not None:
            self.code = code
        if message is not None:
            self.message = message
        if required_agreement is not None:
            self.required_agreement = required_agreement
        if validations is not None:
            self.validations = validations

    @property
    def code(self):
        """Gets the code of this Error.  # noqa: E501


        :return: The code of this Error.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this Error.


        :param code: The code of this Error.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def message(self):
        """Gets the message of this Error.  # noqa: E501


        :return: The message of this Error.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this Error.


        :param message: The message of this Error.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def required_agreement(self):
        """Gets the required_agreement of this Error.  # noqa: E501


        :return: The required_agreement of this Error.  # noqa: E501
        :rtype: object
        """
        return self._required_agreement

    @required_agreement.setter
    def required_agreement(self, required_agreement):
        """Sets the required_agreement of this Error.


        :param required_agreement: The required_agreement of this Error.  # noqa: E501
        :type: object
        """

        self._required_agreement = required_agreement

    @property
    def validations(self):
        """Gets the validations of this Error.  # noqa: E501


        :return: The validations of this Error.  # noqa: E501
        :rtype: object
        """
        return self._validations

    @validations.setter
    def validations(self, validations):
        """Sets the validations of this Error.


        :param validations: The validations of this Error.  # noqa: E501
        :type: object
        """

        self._validations = validations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Error, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Error):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
